@@ -27,8 +27,14 @@ pub enum ErrorKind {
 	BadTypeCode,
 	ExpectedArray,
 	ExpectedArrayEnd,
+	ExpectedFormatSignature,
+	ExpectedEnd,
+	ExpectedScalar,
+	NotExpectingArray,
+	NotExpectingSection,
 	BadUnicodeScalar,
-	ExpectedFormatSignature
+	SizeHintMismatch,
+	CompoundMissingArrayType,
 }
 
 #[derive(Clone, Debug, PartialEq)]
