@@ -8,9 +8,9 @@ pub mod varint;
 mod byte_counter;
 
 // Conventional serde package structure
-pub use de::{from_bytes, deserialize_from};
+pub use de::{from_bytes, from_reader};
 pub use error::{Error, Result, ErrorKind};
-pub use ser::{to_bytes, serialize_into, serialized_size};
+pub use ser::{to_bytes, to_writer, serialized_size};
 
 // EPEE-specific data types
 pub use section::Section;
